@@ -11,8 +11,8 @@ NULL
 #'   \item{markName}{name of mark}
 #'   \item{markColor}{use R colors}
 #'   \item{style}{character, use square or dots, optional}
-#'   \item{protruding}{numeric, modifies aspect of cM/cMLeft marks, see 
-#' parameter 
+#'   \item{protruding}{numeric, modifies aspect of cM/cMLeft marks, see
+#' parameter
 #' \code{protruding} in \code{\link{plotIdiograms}}, optional}
 #' }
 #' @seealso \code{\link{plotIdiograms}}
@@ -22,12 +22,15 @@ NULL
 #' @rdname dfMarkStyle
 "dfMarkColor"
 #' @description humMarkColor: human bands' characteristics, from Adler (1994)
-#' @source 
+#' @source
 #' \url{http://www.pathology.washington.edu/research/cytopages/idiograms/human/}
-#' @references Adler 1994. Idiogram Album. URL: 
+#' @references Adler 1994. Idiogram Album. URL:
 #' \url{http://www.pathology.washington.edu/research/cytopages/idiograms/human/}
 #' @rdname dfMarkStyle
 "humMarkColor"
 #' @description mydfMaColor: mark characteristics used in vignette of phylogeny
 #' @rdname dfMarkStyle
 "mydfMaColor"
+#' @description dfMarkColor5S25S: mark characteristics used in circular plot vignette
+#' @rdname dfMarkStyle
+"dfMarkColor5S25S"
